parserFwk.pyparsing.GoToColumn

Package parserFwk :: Module pyparsing :: Class GoToColumn |
[frames | no frames]

## Type GoToColumn

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
           _PositionToken --+
                            |
                           GoToColumn

Token to advance to a specific column of input text; useful for tabular report scraping.

Method Summary
| `__init__(self, colno)`
| `parseImpl(self, instring, loc, doActions)`
| `preParse(self, instring, loc)`
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__getattr__`, `__invert__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__ror__`, `__rxor__`, `__str__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `enablePackrat`, `getException`, `ignore`, `leaveWhitespace`, `normalizeParseActionArgs`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `skipIgnorables`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Generated by Epydoc 2.1 on Sun Oct 07 01:31:52 2007 | http://epydoc.sf.net